@@ -3,6 +3,7 @@ import os
 import sys
 import argparse
 import subprocess
+from platform import python_version
 from python_starter.core import Project
 from python_starter.template.license_tmpl import candidate
 from python_starter import __version__
@@ -73,11 +74,15 @@ class PythonStarter(object):
         self.parser = PythonStarterParser(
             prog='python-starter',
             add_help=False,
-            usage='%(prog)s [options] target',
+            usage='%(prog)s [options] target...',
             formatter_class=PythonStarterFormatter)
         self.parser._optionals.title = 'options'
         self.parser.add_argument(
-            'name', type=str, metavar='target', help=argparse.SUPPRESS)
+            'name',
+            type=str,
+            metavar='target',
+            nargs='+',
+            help=argparse.SUPPRESS)
         self.parser.add_argument(
             '--author',
             type=str,
@@ -109,20 +114,23 @@ class PythonStarter(object):
         self.parser.add_argument(
             '--version',
             action='version',
-            version='%(prog)s {version}'.format(version=__version__))
+            version='%(prog)s {0} (python {1})'.format(__version__,
+                                                       python_version()))
         self.parser.add_argument(
             '--help', action='help', help='show this message and exit\n ')
 
     def run(self):
         args = self.parser.parse_args().__dict__
-        project = Project(**args)
-        project.make()
-        if self.git_enabled:
-            with open(os.path.devnull, 'w') as fp:
-                subprocess.call(
-                    'git init {}'.format(args['name']).split(),
-                    stdout=fp,
-                    stderr=subprocess.STDOUT)
+        targets = args.pop('name')
+        for target in targets:
+            project = Project(name=target, **args)
+            project.make()
+            if self.git_enabled:
+                with open(os.path.devnull, 'w') as fp:
+                    subprocess.call(
+                        'git init {}'.format(target).split(),
+                        stdout=fp,
+                        stderr=subprocess.STDOUT)
 
 
 def main():
